/***********************************************************************
 *
 * FileName:
 *		PnpNet.h
 *
 * Description:
 *    Declaration of network access functions for "Palm Network
 *    Programming" sample application.
 *
 * Copyright  2000, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

#ifndef __PNPNET_H__
#define __PNPNET_H__

// Standard application definitions
#include "PnpDefs.h"

// Network state constants.
#define pnpNetStateUninit       0
#define pnpNetStateInit         1
#define pnpNetStateConnect      2
#define pnpNetStateDisconnect   3

/*
   PnpNetState:
   Get the current state of the Network subsystem.
   Params:  (none)
   Returns: Current state of network subsystem.
*/
UInt16 PnpNetState (void);

/*
   PnpNetInit:
   Initialize the Network subsystem.  Checks for the
   existance and version of the net library, then
   obtains a reference number to it.
   Params:  (none)
   Returns: 0        Success.
            < 0      Error.
*/
Err PnpNetInit (void);

/*
   PnpNetConnect:
   Connect to the network
   Params:  (none)
   Returns: 0        Success.
            1        Success, but one or more interfaces failed.
            < 0      Error.
*/
Err PnpNetConnect (void);

/*
   PnpNetDisconnect:
   Disconnect from the network
   Params:  (none)
   Returns: 0        Success.
            < 0      Error.
*/
Err PnpNetDisconnect (void);

/*
   PnpNetTerm:
   Terminate the Network subsystem.  Checks if the
   net library is still open.  If it is, closes it,
   but with a delay.
   Params:  (none)
   Returns: 0        Success.
   Note:    This function contains no user interface
            code.
*/
Err PnpNetTerm (void);

/*
   PnpNetFindName:
   Retrieve the ip address for a host name.
   Params:  hostNameP      Host name to lookup.
   Returns: > 0            Host ip address.
            0              Error finding host name.
*/
NetIPAddr PnpNetFindName (Char* hostNameP);

/*
   PnpNetFindAddress:
   Retrieve the ip address for a host name.
   Params:  hostAddrP      Host address to lookup.
   Returns: > 0            Host ip address.
            0              Error finding host name.
*/
NetIPAddr PnpNetFindAddress (Char* hostAddrP);

/*
   PnpNetFindService:
   Retrieve the port number for a standard TCP/IP service.
   Params:  protoNameP     Protocol to use (TCP or UDP).
            servNameP      Service to retrieve.
   Returns: > 0            Port number.
            0              Error finding port.
*/
UInt16 PnpNetFindService (Char* protoNameP, Char* servNameP);

#endif	// __PNPNET_H__
