/***********************************************************************
 *
 * FileName:
 *		PnpLog.h
 *
 * Description:
 *    Declaration of logging functions for "Palm Network Programming"
 *    FTP Client sample application.
 *
 * Note:
 *    Because this is example code, most of the error checking and safety
 *    measures (such as setting unlocked pointers to NULL) have been removed.
 *    This would need to be added back for production-ready code.
 *
 * Copyright  2000, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

#ifndef __PNPLOG_H__
#define __PNPLOG_H__

// Standard application definitions
#include "GLog.h"

// --------------------------------------------------------------------
// Public constant declarations
// --------------------------------------------------------------------
#define kNilLog dmAllCategories
#define pnpLogNet (0)
#define pnpLogFtp (1)

// --------------------------------------------------------------------
// Public typedef declarations
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   PnpLogInit:
   Initialize logging session.
   Params:  (none)
   Returns: 0           Success.
            <0          Error.
*/
Err PnpLogInit (void);

/*
   PnpLogTerm:
   Terminate logging subsystem.
   Params:  (none)
   Returns: 0           Success.
            <0          Error.
*/
Err PnpLogTerm (void);

/*
   PnpLogNumItems:
   Get the number of items in a log.
   Params:  logID       Index of log.
   Returns: >=0         Number of items in log.
            <0          Error.
*/
Int16 PnpLogNumItems (UInt16 logID);

/*
   PnpLogGetItem:
   Retrieve an item from the log.
   Params:  logID       Index of log.
            index       Index of item in log.
            textP       Out-param for log item.
            sizeP       [in]  Max size of textP.
                        [out] Number of characters copied to textP.
   Returns: 0           Success.
            <0          Error.
*/
Err PnpLogGetItem (UInt16 logID, UInt16 itemIndex, Char* textP, UInt16* sizeP);

/*
   PnpLogAddCaption:
   Add a caption to the log (bars above and below).
   Params:  logID       Id of log for caption.
            text        Caption text.
   Returns: 0           Success.
            <0          Error.
*/
Err   PnpLogAddCaption (UInt16 logID, Char* text);

/*
   PnpLogAddResources:
   Draw the current resources on the viewport.
   Params:  logID       Id of log for caption.
            text        Caption text.
   Returns: 0           Success.
            <0          Error.
*/
Err PnpLogAddResources (UInt16 logID, Char* text);

/*
   PnpLogAddItem:
   Add an item to the log.
   Params:  logID       Index of log.
            text        Text to draw.
   Returns: 0           Success.
            <0          Error.
*/
Err PnpLogAddItem (UInt16 logID, Char* text);

/*
   PnpLogPurge:
   Purge all items from the log.
   Params:  logID       Category of log to purge.
   Returns: 0           Success.
            <0          Error.
*/
Err PnpLogPurge (UInt16 logID);

#endif	// __PNPLOG_H__
