#ifndef __GBUF_H__
#define __GBUF_H__

// Standard application definitions
#include "GDefs.h"

// --------------------------------------------------------------------
// Public constant declarations
// --------------------------------------------------------------------
#define gbufPrfBufSize 512

// --------------------------------------------------------------------
// Public typedef declarations
// --------------------------------------------------------------------
typedef MemHandle GBufHandle;

// --------------------------------------------------------------------
// Public structure declarations
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   GBufNew:
   Create a new buffer object.
   Params:  size        Requested size for buffer.
   Returns: !Null       Pointer to created buffer.
            Null        Error creating buffer.
*/
GBufHandle GBufNew (UInt16 size);
   
/*
   GBufFree:
   Destroy a buffer object.
   Params:  bufH        Buffer instance to free.
   Returns: (none)
*/
void GBufFree (GBufHandle bufH);
   
/*
   GBufSize:
   Get the size of a buffer.
   Params:  bufH        Buffer instance.
   Returns: >=0         Size of buffer.
            -1          Error.
*/
UInt16 GBufSize (GBufHandle bufH);

/*
   GBufAvail:
   Get the available space of a buffer.
   Params:  bufH        Buffer instance.
   Returns: >= 0        Available space in buffer.
            -1          Error.
*/
UInt16 GBufAvail (GBufHandle bufH);

/*
   GBufEmpty:
   Empty all data in the buffer.
   Params:  bufH        Buffer instance.
   Returns: 0           Success.
*/
Err GBufEmpty (GBufHandle bufH);

/*
   GBufAppend:
   Append a block of data to the end of the buffer.
   Params:  bufH        Buffer instance.
            blockP      Block of data to append.
            size        Size of data block to append.
   Returns: >=0         Number of bytes appended.
            -1          Error.
*/
UInt16 GBufAppend (GBufHandle bufH, UInt8* blockP, UInt16 size);

/*
   GBufAppendF:
   Append a formatted block of text to the end of the buffer.
   Params:  bufH        Buffer instance.
            formatP     Format string.
            ...         Arguments for format.
   Returns: >=0         Number of bytes appended.
            -1          Error.
*/
UInt16 GBufAppendF (GBufHandle bufH, Char* formatP, ...);

/*
   GBufRead:
   Read a block of data from the start of the buffer.
   Params:  bufH        Buffer instance.
            blockP      [In]  If Null, data is simply removed from buffer.
                        [Out] Data has been *moved* from the buffer.
            size        Size to read.
   Returns: >=0         Number of bytes read.
            -1          Error.
*/
UInt16 GBufRead (GBufHandle bufH, UInt8* blockP, UInt16 size);

/*
   GBufGetReadPtr:
   Get a read pointer to the current start of the buffer.
   Params:  bufH        Buffer instance.
            sizeP       [In]  requested size in bytes.
                        [Out] size of buffer that can be read.
   Returns: !Null       Address of start of buffer.
            Null        An error occurred.
   Note:    There must be one call to GBufReleaseReadPtr (see below)
            for each call to GBufGetReadPtr.
*/
const UInt8* GBufGetReadPtr (GBufHandle bufH, UInt16* sizeP);

/*
   GBufReleaseReadPtr:
   Release the read pointer returned by GBufGetReadPtr.
   Params:  bufH        Buffer instance.
   Returns: 0           Success.
            -1          Error.
*/
Err GBufReleaseReadPtr (GBufHandle bufH);

#endif	// __GBUF_H__
