/***********************************************************************
 *
 * FileName:
 *		GQueue.h
 *
 * Description:
 *    Declarations for GLib Queue support.
 *
 * Copyright  2000, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

#ifndef __GQUEUE_H__
#define __GQUEUE_H__

// Standard application definitions
#include "GDefs.h"

// --------------------------------------------------------------------
// Public typedef declarations
// --------------------------------------------------------------------

/*
   GQueCloneFunc:
   Typedef for callback function for cloning queue entries.
   Params:  entryP   Entry to be cloned.
   Returns: !NULL    Cloned version of item.
            NULL     Error cloning item.
*/
typedef MemHandle (*GQueCloneFunc) (MemPtr entryP);

/*
   GQueDeleteFunc:
   Typedef for callback function for deleting queue entries.
   Params:  entryH   Entry to be deleted.
   Returns: 0        Success.
*/
typedef Err (*GQueDeleteFunc) (MemHandle entryH);

// --------------------------------------------------------------------
// Public structure declarations
// --------------------------------------------------------------------
typedef struct tagGQueue {
   MemHandle theQueue;
   UInt16 queueSize;
   UInt16 numEntries;
} GQueue, * GQueuePtr;

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   GQueInit:
   Initialize a queue
   Params:  qP          Queue instance.
            size        Size of queue. (Currently queues are fixed length).
   Returns: 0        Success.
            <0       Error code.
*/
Err GQueInit (GQueuePtr qP, UInt16 size);

/*
   GQueTerm:
   Terminate a queue.
   Params:  qP       Queue instance.
   Returns: 0        Success.
            <0       Error code.
*/
Err GQueTerm (GQueuePtr qP);

/*
   GQueClear:
   Clear all entries from a queue instance.
   Params:  qP       Queue instance.
   Returns: 0        Success.
            <0       Error code.
*/
Err GQueClear (GQueuePtr qP);

/*
   GQueNumEntries:
   Get the number of entries on the queue.
   Params:  qP       Queue instance.
   Returns: >=0      Number of entries on the queue.
*/
UInt16 GQueNumEntries (GQueuePtr qP);

/*
   GQueEnqueue:
   Enqueue a value from the queue.
   Params:  qP             Pointer to FTP Session information.
            entry          Entry to enqueue.
   Returns: 0              Success.
            glibErrFull    No room for queue item.
            glibErrMemory  Unable to clone item.
*/
Err GQueEnqueue (GQueuePtr qP, Int16 entry);

/*
   GQueDequeue:
   Dequeue an entry on the queue.
   Params:  qP             Pointer to FTP Session information.
   Returns: Value of next item on queue, or -1 if none.
            glibErrNoData  No entries on the queue.
*/
Int16 GQueDequeue (GQueuePtr qP);

/*
   GQuePeek:
   Peek at the first entry on the queue.
   Params:  qP             Pointer to FTP Session information.
   Returns: Value of next item on queue, or -1 if none.
            glibErrNoData  No entries on the queue.
*/
Int16 GQuePeek (GQueuePtr qP);

/*
   GQuePurge:
   Purge all entries from a queue.
   Params:  qP             Pointer to FTP Session information.
   Returns: 0              Success.
            glibErrNoData  No entries on the queue.
*/
Err GQuePurge (GQueuePtr qP);

#endif	// __GQUEUE_H__
